Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1123)

Unified Diff: chrome/browser/ui/views/frame/opaque_browser_frame_view.h

Issue 7138003: Revert 88683 - Change profile menu button to avatar button (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 9 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/opaque_browser_frame_view.h
===================================================================
--- chrome/browser/ui/views/frame/opaque_browser_frame_view.h (revision 88685)
+++ chrome/browser/ui/views/frame/opaque_browser_frame_view.h (working copy)
@@ -18,7 +18,9 @@
namespace gfx {
class Font;
}
-class AvatarMenuButton;
+class ProfileMenuButton;
+class ProfileMenuModel;
+class ProfileTagView;
class TabContents;
namespace views {
class ImageButton;
@@ -142,12 +144,14 @@
void PaintMaximizedFrameBorder(gfx::Canvas* canvas);
void PaintTitleBar(gfx::Canvas* canvas);
void PaintToolbarBackground(gfx::Canvas* canvas);
+ void PaintOTRAvatar(gfx::Canvas* canvas);
void PaintRestoredClientEdge(gfx::Canvas* canvas);
// Layout various sub-components of this view.
void LayoutWindowControls();
void LayoutTitleBar();
- void LayoutAvatar();
+ void LayoutOTRAvatar();
+ void LayoutProfileTag();
// Returns the bounds of the client area for the specified view size.
gfx::Rect CalculateClientAreaBounds(int width, int height) const;
@@ -155,11 +159,14 @@
// Receive notifications when the user's Google services user name changes.
void RegisterLoginNotifications();
+ // Returns true if the ProfileButton has been created.
+ bool show_profile_button() const { return profile_button_.get() != NULL; }
+
// The layout rect of the title, if visible.
gfx::Rect title_bounds_;
- // The layout rect of the avatar icon, if visible.
- gfx::Rect avatar_bounds_;
+ // The layout rect of the OTR avatar icon, if visible.
+ gfx::Rect otr_avatar_bounds_;
// Window controls.
views::ImageButton* minimize_button_;
@@ -179,10 +186,12 @@
// The bounds of the ClientView.
gfx::Rect client_view_bounds_;
- // Menu button that displays that either the incognito icon or the profile
- // icon.
- scoped_ptr<AvatarMenuButton> avatar_button_;
+ // Menu button that displays user's name and multi-profile menu.
+ scoped_ptr<ProfileMenuButton> profile_button_;
+ // Image tag displayed on frame beneath profile_button_.
+ scoped_ptr<ProfileTagView> profile_tag_;
+
// The Google services user name associated with this BrowserView's profile.
StringPrefMember username_pref_;
« no previous file with comments | « chrome/browser/ui/views/frame/glass_browser_frame_view.cc ('k') | chrome/browser/ui/views/frame/opaque_browser_frame_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698